"""
#######################################################################
#
# Licensed Materials - Property of Pipelinefx L.L.C.
#
#
# (C) COPYRIGHT Pipelinefx Limited Liability Corporation.
#  All Rights Reserved.
#                               
#  US Government Users Restricted Rights - Use, duplication or
#  disclosure restricted by GSA ADP Schedule Contract with 
#  Pipelinefx L.L.C.
#
# $DateTime: 2013/07/08 14:29:16 $
# $Revision: #3 $
# $Change: 11473 $
# $File: //depot/main/qubeMobileServer/config/qubeMobileServerSettings.py $
#
# Written by: Brian Knudson / PFX
#             briank@pipelinefx.com
#
# Description:
#  Parse and store config settings for qubeMobileServer
#
# Notes:
#
#######################################################################
"""

import os
import re
import logging
import string

class QubeMobileServerSettings(object):
    def __init__(self,conf_file="./qbms.conf"):
        logging.debug("Using settings file '%s'" % conf_file)
        self.variable_names = []
        self.conf_file = conf_file
        if os.path.exists(conf_file):
            self.__parseFile(conf_file)
        else:
            logging.error("Cannot read conf file '%s'" % conf_file)
            # force exception (lazy)
            open(conf_file,'r')

    def __str__(self):
        max_len = max(map(len,self.variable_names))
        ret = ""
        for v in self.variable_names:
            ret += "%*s %s\n" % (max_len,v,vars(self)[v])
        return ret

    def __parseFile(self,filename):
        """
        Parses the file 'filename' & stores all the values local to the class
        """
        contents = [line for line in re.sub('#.*|\"','',open(filename).read()).split('\n') if line]
        for c in contents:
            k,v = map(string.strip,c.split('='))
            try:
                if v.lower() == "true" or v.lower() == "false":
                    v = eval(v.capitalize())
            except:
                pass
            try:
                if v.isdigit():
                    v = int(v)
            except:
                pass
            logging.debug("Settings setting '%s' = '%s'" % (k,v))
            vars(self)[k] = v
            self.variable_names.append(k)

    def get(self,var,default=None):
        """
        Like dict.get()
        """
        return getattr(self,var,default)

    def update(self,update_dict):
        """
        Uses the dictionary 'update_dict' to update our internal variables
        """
        for k,v in update_dict.items():
            logging.debug("Settings updating '%s' = '%s'" % (k,v))
            vars(self)[k] = v
        
