"""
#######################################################################
#
# Licensed Materials - Property of Pipelinefx L.L.C.
#
#
# (C) COPYRIGHT Pipelinefx Limited Liability Corporation.
#  All Rights Reserved.
#                               
#  US Government Users Restricted Rights - Use, duplication or
#  disclosure restricted by GSA ADP Schedule Contract with 
#  Pipelinefx L.L.C.
#
# $DateTime: 2014/03/20 07:43:09 $
# $Revision: #10 $
# $Change: 12273 $
# $File: //depot/main/qubeMobileServer/qubeMobile/controller/qbController.py $
#
# Written by: Brian Knudson / PFX
#             briank@pipelinefx.com
#             2012-06-04
#
# Description:
#  'C' of the MVC that is qubeMobileServer.
#
# Notes:
#  
#
#######################################################################
"""
import time
import re
import os
import urllib
from mako.template import Template
from mako.lookup   import TemplateLookup
from mako import exceptions
from qubeMobile.model.qbUIJobList import QbUIJobList

class QbController(object):
    """
    Controller for qubeMobileServer.  This module will call the correct
    template based on the request that comes through 'handle'.
    When you create a QbController module, you can pass an optional
    'refresh_interval'.  This determines the number of seconds after
    which the job cache is considered stale.  At this point, the job
    list is cleared and repopulated.  This can be an expensive operation,
    so a large interval is recommended.  During the cached period, the
    job list will still update, but the removal of jobs will not be
    reflected in the interface until the job cache is cleared.  The default
    refresh_interval is 600 seconds (10 minutes).
    """
    def __init__(self,job_list,refresh_interval=600,template_dir=None):
        self.refresh_interval = refresh_interval
        self.last_refreshed = int(time.time())
        self.job_list = job_list
        my_dir = os.path.dirname(os.path.dirname(__file__))
        view_dir = os.path.join(my_dir,"view")
        if not template_dir: template_dir = '.'
        self.lookup = TemplateLookup(directories=[view_dir,'./qubeMobile/view',template_dir])
        self.job_pat = re.compile(".*job.\d+$")

    def handle(self,path,session=None,allow_control=False,**kwargs):
        # if the path is a request for a job, then present just the job detail template
        if re.match(self.job_pat,path):
            try:
                job_template = self.lookup.get_template("job_detail_template.html")
                job = self.job_list[int(path.split('.')[-1])]
                job.updateDetail()
                # pack some extra stuff into "session" so we can send it all at once
                # (this is probably lazy... welcome to v1.0)
                session['job']=job
                session['allow_control'] = allow_control
                msg = urllib.unquote_plus(kwargs.get('msg',''))
                if msg:
                    session['msg'] = msg
                return job_template.render(**session)
            except:
                return exceptions.html_error_template().render()

        # authentication:
        elif path.find("authenticate") >= 0:
            page_template = self.lookup.get_template("auth_template.html")
            session['reason'] = urllib.unquote_plus(kwargs.get('reason',''))
            session.setdefault('auth',False)
            return page_template.render(**session)
        
        # settings:
        elif path.find("settings") >= 0:
            page_template = self.lookup.get_template("settings_template.html")
            session['reason'] = urllib.unquote_plus(kwargs.get('reason',''))
            return page_template.render(**session)
            
            

        # otherwise, present the job list template.
        else:
            try:
                # Check to see if we need to clear our cache...
                if int(time.time()) - self.last_refreshed > self.refresh_interval:
                    self.job_list.updateJobList(clear=True)
                    self.last_refreshed = int(time.time())
                else:
                    self.job_list.updateJobList()                 

                # If given a user, filter the results on the way to the template
                if session.get('user',False) and session.get('only_my_jobs'):
                    user = session['user']
                    jobs = dict([(jid,job) for jid,job in self.job_list.items() if job['user'] == user])
                else:
                    session['user']='All'
                    jobs = self.job_list

                # Get the template & render it
                job_template = self.lookup.get_template("job_list_template.html")
                # pack some extra stuff into "session" so we can send it all at once
                # (this is probably lazy... welcome to v1.0)
                session['jobs']=jobs
                session['allow_control'] = allow_control
                return job_template.render(**session)
            except:
                # go ahead and display the exception to the client & let them complain to their
                # admin rather than silently fail & pretend like nothing happened
                return exceptions.html_error_template().render()
                
