"""
#######################################################################
#
# Licensed Materials - Property of Pipelinefx L.L.C.
#
#
# (C) COPYRIGHT Pipelinefx Limited Liability Corporation.
#  All Rights Reserved.
#                               
#  US Government Users Restricted Rights - Use, duplication or
#  disclosure restricted by GSA ADP Schedule Contract with 
#  Pipelinefx L.L.C.
#
#
# QubeView Main Window
#
# Name: qubeArtistView.py
#
# $DateTime: 2013/07/08 14:29:16 $
# $Revision: #1 $
# $Change: 11473 $
# $Id: //depot/main/qubeMobileServer/qubeMobile/model/objCheckUtils.py#1 $
# $File: //depot/main/qubeMobileServer/qubeMobile/model/objCheckUtils.py $
#
# Written by: Brian Knudson / PFX
#             briank@pipelinefx.com
#             2012-04-26
#
# Description:
#  Utility functions that look through the garbage collector & report
#  back what it holds... useful for tracking memory leaks and/or
#  cyclic references that cause memory "leaks".
#
#######################################################################
"""

import gc
import operator

def typestats():
    """
    Return the number of instances of each object
    that is tracked by the gc
    """
    stats = {}
    for o in gc.get_objects():
        stats.setdefault(type(o).__name__, 0)
        stats[type(o).__name__] += 1
    return stats


def showMostCommonTypes(limit=10):
    """
    Return the counts of the most common objects/types
    tracked by the gc
    """
    stats = sorted(typestats().items(), key=operator.itemgetter(1),
                   reverse=True)
    if limit:
        stats = stats[:limit]
    width = max(len(name) for name, count in stats)
    ret = []
    for name, count in stats[:limit]:
        ret.append("%s%s" % (name.ljust(width), count))

    return ret
