"""
 Licensed Materials - Property of Pipelinefx L.L.C.


 (C) COPYRIGHT Pipelinefx Limited Liability Corporation.
  All Rights Reserved.
                               
  US Government Users Restricted Rights - Use, duplication or
  disclosure restricted by GSA ADP Schedule Contract with 
  Pipelinefx L.L.C.

 $DateTime: 2014/03/20 07:43:09 $
 $Revision: #2 $
 $File: //depot/main/qubeMobileServer/qubeMobile/model/qbUIBase.py $

 Written by: Brian Knudson / PFX
             briank@pipelinefx.com
             2011-10-05

 Description:
  Base class for non-list-type classes.  Provides some basic
  functionality that they should all have

"""

import logging

class QbUIBase(object):
    def getAttribute(self,attr_map):
        """
        takes an attibute map (of which the static class variable 'attribute_map'
        defines several) and returns the correct database based on the attribute map
        """
        if not isinstance(attr_map,dict):
            if isinstance(self.getAttributeMap(name=attr_map)[0],dict):
                attr_map = self.getAttributeMap(name=attr_map)[0]
            elif isinstance(self.getAttributeMap(attribute=attr_map)[0],dict):
                attr_map = self.getAttributeMap(attribute=attr_map)[0]
            elif isinstance(self.getAttributeMap(display=attr_map)[0],dict):
                attr_map = self.getAttributeMap(display=attr_map)[0]
            else:
                tmp = {}
                tmp["attribute"] = attr_map
                attr_map = tmp

        name = attr_map.get("name",None)
        # This is to handle 6.5 maps in 6.6:
        if not name:
            name = attr_map.get("attribute",None)
            if not name:
                name = attr_map.get("display",None)
        display = attr_map.get("display",name)
        attribute_list = [attr_map.get("attribute",name)]
        format = attr_map.get("format","%s")

        if attribute_list[0].count(':'):
            attribute_list = attribute_list[0].split(':')

        attr_string = "self"
        for i,attr in enumerate(attribute_list):
            if attr.count(";"):
                logging.error("Invalid chacter in attribute map: %s" % attr)
                return "--"
            if attr.endswith("()"):
                attr_string += ".%s" % attr
            elif attr not in self.keys() and i == 0:
                attr_string += ".%s" % attr
            else:
                attr_string += "['%s']" % attr

        try:
            return format % eval(attr_string)
        except TypeError:
            return unicode(eval(attr_string))
        except:
            return "--"

    def getAttributeMap(self,attr_map=None,**kwargs):
        """
        Searches for the map for this object.  **kwargs can be any of the keys/values for
        an attribute map, i.e. display='My Progress' or attribute='id'
        In the event that multiple kwargs are given, they will be anded together.
        if attr_map is passed in, then the use that map instead of the static local
        The return is a list of matching maps
        """
        if not attr_map:
            attr_map = self.attribute_map
        ret = []
        for attr in attr_map:
            match = True
            for k,v in kwargs.items():
                if attr.get(k,None) != v:
                    match = False
                    break
            if match:
                ret.append(attr)

        # if we didn't find it with the custom map, look in the standard map
        if not ret and attr_map:
            return self.getAttributeMap(kwargs)
        return ret
            
