"""
 Licensed Materials - Property of Pipelinefx L.L.C.


 (C) COPYRIGHT Pipelinefx Limited Liability Corporation.
  All Rights Reserved.
                               
  US Government Users Restricted Rights - Use, duplication or
  disclosure restricted by GSA ADP Schedule Contract with 
  Pipelinefx L.L.C.

 $DateTime: 2013/07/08 14:29:16 $
 $Revision: #3 $
 $Change: 11473 $
 $File: //depot/main/qubeMobileServer/qubeMobile/model/qbUIUserList.py $

 Written by: Brian Knudson / PFX
             briank@pipelinefx.com
             2011-10-05

 Description:
  UIUserList class - Holds a list of a Users with sensible access
  to user methods.

"""

import os
import sys
import re
import time
import datetime
import logging

try:
    import qb
except ImportError:
    api_path = "/Applications/pfx/qube/api/python/"
    if api_path not in sys.path:
        sys.path.insert(0,api_path)
    import qb


from qbUIList import QbUIList
from qbUIUser import QbUIUser



class QbUIUserList(QbUIList):
    """
    A user list model.
    Can be contructed:
      blank: which will get all users from the db
      list: will create an internal dict from the list of users
      dict: will copy the given dict to internal
    """
    def __init__(self, permissions={}):
        logging.debug("Creating QbUiUserList")
        self.updateUserList(user_list=permissions)


    def __getitem__(self,key):
        """
        Implementation of self[key] on the fetching side.
        self[key] will be a qb.Job.
        """
        try:
            val = self._data[key]
        except KeyError:
            # if the given user doesn't exist in the list, return the default user
            logging.debug("Returning default user for '%s'" % key)
            val = self._data['']
        return val


    def updateUserList(self,user_list=None):
        """
        Populates internal dictionary with the return of an API call.
        Params:
          clear=False:  If clear is True, the internal dict is cleared before being populated
                        If clear is False (default), only the entries in the internal dict that
                         are newer than our internal timestamp are updated.
          userList=None: If supplied, use this last rather than fetching one via the api.
          job_list=None: If supplied, pass the joblist through to each user
        Pre-condition: None
        Post-condition: internal dictionary has complete of partial new data
        Return value: None
        """

        self._data = {}

        if not user_list:
            user_list = qb.getusers()

        # updated the list with what we just got.  Dirty up the entry so we know it's new
        for k,v in user_list.items():
            self._data[k] = QbUIUser(username=k,permissions=v)

        logging.info("Updated %d users(s)" % (len(user_list)))

        
