/************************************************************************
*
* Licensed Materials - Property of Pipelinefx L.L.C.
*
*
* (C) COPYRIGHT Pipelinefx Limited Liability Corporation.
*  All Rights Reserved.
*
*  US Government Users Restricted Rights - Use, duplication or
*  disclosure restricted by GSA ADP Schedule Contract with
*  Pipelinefx L.L.C.
*
* $DateTime: 2012/07/03 14:03:03 $
* $Revision: #2 $
* $Change: 9792 $
* $File: //depot/main/qubeMobileServer/qubeMobile/static/iphonenav.js $
*
* Written by: Brian Knudson / PFX
*             briank@pipelinefx.com
*             2012-06-04
*
* Description:
*  Javascript navigation utils for mobile server
*
* Notes:
*
************************************************************************/

(function() {

var animateX = -20;
var animateInterval = 24;

var currentPage = null;
var currentDialog = null;
var currentWidth = 0;
var currentHash = location.hash;
var hashPrefix = "#";
var pageHistory = [];

addEventListener("load", function(event)
{
    var body = document.getElementsByTagName("body")[0];
    for (var child = body.firstChild; child; child = child.nextSibling)
    {
        if (child.nodeType == 1 && child.getAttribute("selected") == "true")
        {
	    showPage(child);
	    // showPage(child,1);
            break;
        }
    }

    setInterval(checkOrientAndLocation, 300);
    setTimeout(scrollTo, 0, 0, 1);
}, false);

addEventListener("click", function(event)
{
    // event.preventDefault();

    var link = event.target;
    try
      {
      while (link && link.localName.toLowerCase() != "a")
	link = link.parentNode;
      }
    catch(err)
      {

      }

    if (link && link.hash)
    {
        currentHash = location.hash;

        // var pageId = currentHash.substr(hashPrefix.length);
        // var page = document.getElementById(pageId);
	var page = document.getElementById(link.hash.substr(1));
	var pageId = page.id
        if (page)
        {
            var index = pageHistory.indexOf(pageId);

            var backwards = index != -1;
            if (backwards)
               pageHistory.splice(index, pageHistory.length);
	    showPage(page, backwards);
        }
	// showPage(page,1);
    }


}, true);

function checkOrientAndLocation()
{
    if (window.outerWidth != currentWidth)
    {
        currentWidth = window.outerWidth;

        var orient = currentWidth == 320 ? "profile" : "landscape";
        document.body.setAttribute("orient", orient);
    }

    if (location.hash != currentHash)
    {
        currentHash = location.hash;

        var pageId = currentHash.substr(hashPrefix.length);
        var page = document.getElementById(pageId);
        if (page)
        {
            var index = pageHistory.indexOf(pageId);
            var backwards = index != -1;
            if (backwards)
                pageHistory.splice(index, pageHistory.length);

            showPage(page, backwards);
        }
    }
}

function showPage(page, backwards)
{
    if (currentDialog)
    {
        currentDialog.removeAttribute("selected");
        currentDialog = null;
    }

    if (page.className.indexOf("dialog") != -1)
        showDialog(page);
    else
    {
      location.href = currentHash = hashPrefix + page.id;
      pageHistory.push(page.id);

        var fromPage = currentPage;
        currentPage = page;

        var pageTitle = document.getElementById("pageTitle");
        pageTitle.innerHTML = page.title || "";

        var homeButton = document.getElementById("homeButton");
        if (homeButton)
            homeButton.style.display = ("#"+page.id) == homeButton.hash ? "none" : "inline";

        if (fromPage)
            setTimeout(swipePage, 0, fromPage, page, backwards);
    }
}

function swipePage(fromPage, toPage, backwards)
{
    toPage.style.left = "100%";
    toPage.setAttribute("selected", "true");
    scrollTo(0, 1);

    var percent = 100;
    var timer = setInterval(function()
    {
        percent += animateX;
        if (percent <= 0)
        {
            percent = 0;
            fromPage.removeAttribute("selected");
            clearInterval(timer);
        }

        fromPage.style.left = (backwards ? (100-percent) : (percent-100)) + "%";
        toPage.style.left = (backwards ? -percent : percent) + "%";
    }, animateInterval);
}

function showDialog(form)
{
    currentDialog = form;
    form.setAttribute("selected", "true");

    form.onsubmit = function(event)
    {
        event.preventDefault();
        form.removeAttribute("selected");

        var index = form.action.lastIndexOf("#");
        if (index != -1)
          showPage(document.getElementById(form.action.substr(index+1)));
    };

    form.onclick = function(event)
    {
        if (event.target == form)
            form.removeAttribute("selected");
    };
}



})();
